/*
 * This is a universal config.h file for the R environment
 * It does not need to be customized and was not generated
 * from a configure script
 */
#include <R.h>
#ifndef USING_R
#define USING_R 1
#endif
